declare module 'Cpp'{
    namespace Cpp {
        interface Session{
            /**
             * Randomly generated session id.
             */
            sessionId: string;

            /**
             * Customer id returned from Create Customer request.
             */
            customerId: string;

            /**
             * Complete status of the session.
             */
            sessionComplete: boolean;

            /**
             * Transaction types include: purchase, auth, validate.
             */
            txnType: string;

            /**
             * Amount for payment.
             */
            totalAmount: string;

            /**
             * ISO 4217 3 letter currency code.
             */
            currencyCode: string;

            /**
             * Transaction reference set by API caller.
             */
            clientRef?: string | null;

            /**
             * RFC123 timestamp indicating when the session will expire. Sessions expire 15 minutes after creation.
             */
            expiryTimestamp: string;

            /**
             * Flag to save the payment details for future payment.
             */
            tokenize: boolean;

            /**
             * An encrypted version of the session-id used to load HPP. For example: https://cpp.com/sessions/{HppId}
             */
            hppId: string;

            /**
             * Results of the transaction include: Approved, Declined, Cancelled, Error, Expired
             */
            sessionResult?: string | null;

            /**
             * 
             */
            txn?: Payment.Txn | null;
        }

        interface SessionCreateParams {
            /**
             * Transaction reference set by API caller
             */
            clientRef?: string;

            /**
             * Transaction types include: purchase, auth, validate
             */
            txnType: string;

            /**
             * Customer id generated from the Create Customer request.
             */
            customerId?: string | null;

            /**
             * ISO 4217 3 letter currency code
             */
            currencyCode: string;

            /**
             * Amount for payment
             */
            totalAmount: string;

            /**
             * Flag to save the payment details for future payment.
             */
            tokenize?: boolean | null;
        }

        interface SessionQueryParams {
            /**
             * Session id returned from Create Session request.
             */
            sessionId: string;
        }

        class SessionsResource {
            /**
             * Creates a new session object.
             */
            create(
              params?: SessionCreateParams,
              options?: RequestOptions
            ): Promise<Cpp.Response<Cpp.Session>>;
            create(
              options?: RequestOptions
            ): Promise<Cpp.Response<Cpp.Session>>;

            /**
             * Quries a session object.
             */
             query(
                params?: SessionQueryParams,
                options?: RequestOptions
              ): Promise<Cpp.Response<Cpp.Session>>;
              query(
                options?: RequestOptions
              ): Promise<Cpp.Response<Cpp.Session>>;
        }
    }
}